(function($) {
    'use strict';

    $(function() {
        // Media Library optimization button
        $(document).on('click', '.altomatic-optimize', function(e) {
            e.preventDefault();
            
            const $button = $(this);
            const attachmentId = $button.data('id');
            
            if (!attachmentId) {
                return;
            }
            
            $button.prop('disabled', true)
                .text(altomatic_data.labels.optimizing)
                .addClass('button-busy');
            
            $.ajax({
                url: altomatic_data.ajax_url,
                type: 'POST',
                data: {
                    action: 'altomatic_optimize_attachment',
                    attachment_id: attachmentId,
                    nonce: altomatic_data.nonce
                },
                success: function(response) {
                    if (response.success) {
                        const data = response.data;
                        
                        // Create HTML for the status display
                        let html = '<div class="altomatic-status">';
                        html += '<span class="altomatic-status-optimized">' + altomatic_data.labels.optimized + '</span>';
                        
                        if (data.savings && data.percentage) {
                            html += '<span class="altomatic-savings">' + data.savings + ' (' + data.percentage + ')</span>';
                        }
                        
                        // Add WebP badge if available
                        if (data.has_webp) {
                            html += '<div class="altomatic-webp-status">';
                            html += '<span class="altomatic-webp-badge">WebP</span>';
                            html += '<span class="altomatic-webp-sizes">' + data.webp_sizes.join(', ') + '</span>';
                            html += '</div>';
                        }
                        
                        html += '</div>';
                        
                        // Replace the button with status info
                        $button.replaceWith(html);
                        
                        // If in the attachment details modal, update that too
                        if (wp.media.frame && wp.media.frame.content.get()) {
                            // Force refresh of the details view
                            wp.media.frame.content.get().refresh();
                        }
                    } else {
                        $button.prop('disabled', false)
                            .removeClass('button-busy')
                            .text(altomatic_data.labels.optimize);
                            
                        alert(response.data.message || 'Error optimizing image.');
                    }
                },
                error: function() {
                    $button.prop('disabled', false)
                        .removeClass('button-busy')
                        .text(altomatic_data.labels.optimize);
                        
                    alert('Error connecting to the server. Please try again.');
                }
            });
        });
    });

    /**
     * Validate API key with the server
     */
    function validateApiKey(apiKey) {
        $.ajax({
            url: altomaticAdmin.ajaxurl,
            type: 'POST',
            data: {
                action: 'altomatic_validate_api_key',
                nonce: altomaticAdmin.nonce,
                api_key: apiKey
            },
            beforeSend: function() {
                // Show loading state
                $('#api-key-status').html('<span class="altomatic-status altomatic-status-warning">Validating...</span>');
            },
            success: function(response) {
                if (response.success) {
                    $('#api-key-status').html('<span class="altomatic-status altomatic-status-success">Valid</span>');
                } else {
                    $('#api-key-status').html('<span class="altomatic-status altomatic-status-error">Invalid</span>');
                }
            },
            error: function() {
                $('#api-key-status').html('<span class="altomatic-status altomatic-status-error">Error validating</span>');
            }
        });
    }

})(jQuery); 