<?php
// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

// Get current settings
$auto_generate_alt = get_option('altomatic_auto_generate_alt', true);
$format_conversion = get_option('altomatic_format_conversion', array('keep', 'webp', 'avif'));
$image_sizes = get_option('altomatic_image_sizes', array('full', 'thumbnail', 'medium', 'medium_large', 'large'));

// Format settings for display
$format_labels = array(
    'keep' => __('Original', 'altomatic'),
    'webp' => 'WebP',
    'avif' => 'AVIF'
);

$size_labels = array(
    'full' => __('Full Size', 'altomatic'),
    'thumbnail' => __('Thumbnail', 'altomatic'),
    'medium' => __('Medium', 'altomatic'),
    'medium_large' => __('Medium Large', 'altomatic'),
    'large' => __('Large', 'altomatic')
);


?>

<div class="wrap altomatic-bulk">
    <h1><?php esc_html_e('Altomatic Bulk Optimization', 'altomatic'); ?></h1>

    <div class="altomatic-bulk-container">
        <div class="altomatic-settings-summary">
            <h2><?php esc_html_e('Current Settings', 'altomatic'); ?></h2>
            <div class="altomatic-settings-grid">
                <div class="altomatic-setting">
                    <h3><?php esc_html_e('Altomatic AI Alt Text', 'altomatic'); ?></h3>
                    <p><?php echo $auto_generate_alt ? esc_html__('Enabled', 'altomatic') : esc_html__('Disabled', 'altomatic'); ?></p>
                </div>
                <div class="altomatic-setting">
                    <h3><?php esc_html_e('Image Formats', 'altomatic'); ?></h3>
                    <p><?php echo esc_html(implode(', ', array_map(function($format) use ($format_labels) {
                        return $format_labels[$format] ?? $format;
                    }, $format_conversion))); ?></p>
                </div>
                <div class="altomatic-setting">
                    <h3><?php esc_html_e('Image Sizes', 'altomatic'); ?></h3>
                    <p><?php echo esc_html(implode(', ', array_map(function($size) use ($size_labels) {
                        return $size_labels[$size] ?? $size;
                    }, $image_sizes))); ?></p>
                </div>
            </div>
            <div class="altomatic-settings-actions">
                <a href="<?php echo esc_url(admin_url('options-general.php?page=altomatic')); ?>" class="button altomatic-button">
                    <?php esc_html_e('Change Settings', 'altomatic'); ?>
                </a>
            </div>
        </div>

        <div class="altomatic-bulk-stats">
            <h2><?php esc_html_e('Images to Process', 'altomatic'); ?></h2>
            <div class="altomatic-stats-grid">
                <div class="altomatic-stat-box">
                    <h3><?php esc_html_e('Unoptimized Images', 'altomatic'); ?></h3>
                    <div class="altomatic-count-container">
                        <span class="altomatic-unoptimized-count">-</span>
                        <span class="altomatic-count-label"><?php esc_html_e('images', 'altomatic'); ?></span>
                    </div>
                </div>
                <div class="altomatic-stat-box">
                    <h3><?php esc_html_e('Missing AI Alt Text', 'altomatic'); ?></h3>
                    <div class="altomatic-count-container">
                        <span class="altomatic-missing-alt-count">-</span>
                        <span class="altomatic-count-label"><?php esc_html_e('images', 'altomatic'); ?></span>
                    </div>
                </div>
            </div>
        </div>

        <div class="altomatic-bulk-actions">
            <div id="altomatic-no-images" class="notice notice-success" style="display: none;">
                <p><?php esc_html_e('All images are optimized and up to date!', 'altomatic'); ?></p>
            </div>
            <button id="start-bulk-optimization" class="button button-primary altomatic-button" style="display: none;">
                <?php esc_html_e('Start Bulk Processing', 'altomatic'); ?>
            </button>
        </div>

        <div class="altomatic-progress-container" style="display: none;">
            <div class="altomatic-progress-bar">
                <div class="altomatic-progress" style="width: 0%"></div>
            </div>
            <div class="altomatic-progress-stats">
                <span class="altomatic-optimized-count">0</span> / <span class="altomatic-total-count">0</span>
                <span class="altomatic-percentage">0%</span>
            </div>
        </div>

        <div class="altomatic-status-messages"></div>
    </div>
</div>

<script>
jQuery(document).ready(function($) {
    let isOptimizing = false;
    const BATCH_SIZE = 1;

    // Function to check and update button visibility
    function updateButtonVisibility(unoptimizedCount, missingAltCount) {
        const totalCount = unoptimizedCount + missingAltCount;
        if (totalCount === 0) {
            $('#start-bulk-optimization').hide();
            $('#altomatic-no-images').show();
        } else {
            $('#start-bulk-optimization').show();
            $('#altomatic-no-images').hide();
        }
    }

    // Function to update both counts
    function updateCounts() {
        let unoptimizedCount = 0;
        let missingAltCount = 0;
        let countsFetched = 0;

        // Get unoptimized count
        $.ajax({
            url: altomaticAdmin.ajaxurl,
            type: 'GET',
            data: {
                action: 'altomatic_get_unoptimized_count',
                _ajax_nonce: altomaticAdmin.nonce
            },
            success: function(response) {
                if (response.success) {
                    unoptimizedCount = response.data.count;
                    $('.altomatic-unoptimized-count').text(unoptimizedCount);
                }
                countsFetched++;
                if (countsFetched === 2) {
                    updateButtonVisibility(unoptimizedCount, missingAltCount);
                }
            },
            error: function(xhr, status, error) {
                console.error('Error getting count:', error);
                addStatusMessage('Error getting unoptimized image count: ' + error, 'error');
            }
        });

        // Get missing alt text count
        $.ajax({
            url: altomaticAdmin.ajaxurl,
            type: 'GET',
            data: {
                action: 'altomatic_get_missing_alt_count',
                _ajax_nonce: altomaticAdmin.nonce
            },
            success: function(response) {
                if (response.success) {
                    missingAltCount = response.data.count;
                    $('.altomatic-missing-alt-count').text(missingAltCount);
                }
                countsFetched++;
                if (countsFetched === 2) {
                    updateButtonVisibility(unoptimizedCount, missingAltCount);
                }
            },
            error: function(xhr, status, error) {
                console.error('Error getting alt text count:', error);
                addStatusMessage('Error getting missing alt text count: ' + error, 'error');
            }
        });
    }

    // Initial counts update
    updateCounts();

    // Function to add status message
    function addStatusMessage(message, type = 'info') {
        const messageHtml = `<div class="altomatic-status-message altomatic-status-${type}">${message}</div>`;
        $('.altomatic-status-messages').prepend(messageHtml);
    }

    // Function to clear status messages
    function clearStatusMessages() {
        $('.altomatic-status-messages').empty();
    }

    // Function to update progress
    function updateProgress(processed, total) {
        const percentage = Math.round((processed / total) * 100);
        $('.altomatic-progress').css('width', percentage + '%');
        $('.altomatic-optimized-count').text(processed);
        $('.altomatic-total-count').text(total);
        $('.altomatic-percentage').text(percentage + '%');
    }

    // Function to process a batch of images
    async function processBatch(current_batch, total) {
        try {
            console.log('Processing batch...', current_batch, total);
            const response = await $.ajax({
                url: altomaticAdmin.ajaxurl,
                method: 'POST',
                data: {
                    action: 'altomatic_bulk_optimize',
                    batch_size: BATCH_SIZE,
                    _ajax_nonce: altomaticAdmin.nonce
                }
            });

            if (response.success) {
                // Update progress for the processed image
                const processed = (current_batch + 1) * BATCH_SIZE;
                updateProgress(processed, total);

                // Check if we have more images to process
                if (processed < total) {
                    // Continue with next image after a short delay
                    setTimeout(() => {
                        processBatch(current_batch + 1, total);
                    }, 100);
                } else {
                    // All images processed
                    isOptimizing = false;
                    clearStatusMessages();
                    addStatusMessage('Bulk processing completed successfully!', 'success');
                    $('#start-bulk-optimization').show();
                    // Update counts after completion
                    setTimeout(updateCounts, 500);
                }
            } else {
                // If there's an error give up
                addStatusMessage('Error processing image: ' + (response.data?.message || 'Unknown error'), 'error');

            }
        } catch (error) {
            // If there's an error give up
            addStatusMessage('Error: ' + error.message, 'error');
        }
    }

    // Start bulk optimization
    $('#start-bulk-optimization').on('click', function() {
        if (isOptimizing) return;

        isOptimizing = true;
        clearStatusMessages();
        $('.altomatic-progress-container').show();
        $('#start-bulk-optimization').hide();

        // Get initial count and start processing
        $.ajax({
            url: altomaticAdmin.ajaxurl,
            type: 'GET',
            data: {
                action: 'altomatic_get_unoptimized_count',
                _ajax_nonce: altomaticAdmin.nonce
            },
            success: function(response) {
                if (response.success && response.data.count > 0) {
                    const total = response.data.count; // This is just unoptimized count
                    updateProgress(0, total);
                    processBatch(0, total);
                } else {
                    addStatusMessage('No images to process.', 'info');
                    isOptimizing = false;
                    $('.altomatic-progress-container').hide();
                    $('#start-bulk-optimization').show();
                    updateCounts();
                }
            },
            error: function(xhr, status, error) {
                addStatusMessage('Error getting unoptimized image count: ' + error, 'error');
                isOptimizing = false;
                $('.altomatic-progress-container').hide();
                $('#start-bulk-optimization').show();
            }
        });
    });
});
</script>
