<?php
/**
 * Settings page template
 *
 * @package Altomatic
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

// Get registered image sizes
$image_sizes = get_intermediate_image_sizes();

// Add 'full' size to the list of available sizes
$all_sizes = array_merge(['full'], $image_sizes);

// Get selected sizes from options, with no default fallback
$selected_sizes = get_option('altomatic_image_sizes');
if ($selected_sizes === false) {
    // Only use default on first install
    $selected_sizes = $all_sizes;
}

// Handle format conversion option (might be string from previous version)
$format_option = get_option('altomatic_format_conversion');
if ($format_option === false) {
    // Only use default on first install
    $format_option = array('keep', 'webp');
}
$selected_formats = is_array($format_option) ? $format_option : array($format_option);
?>
<?php
    // Check if credits are exceeded
    $credit_usage = get_option('altomatic_credit_usage', 0);
    $credit_limit = get_option('altomatic_credit_limit', 50); // Default to free tier limit

    if ($credit_usage > $credit_limit) {
        echo '<div class="notice notice-warning is-dismissible">';
        echo '<p><strong>' . esc_html__('Altomatic: Credit Limit Exceeded', 'altomatic') . '</strong></p>';
        echo '<p>' . sprintf(
            /* translators: 1: Current credit usage 2: Credit limit 3: Upgrade link HTML */
            esc_html__('Image optimization and AI alt text generation have been paused because you\'ve used %1$d of %2$d credits. To resume services, please %3$s or wait until your credits reset next month.', 'altomatic'),
            esc_html($credit_usage),
            esc_html($credit_limit),
            '<a href="https://altomatic.ai/profile" target="_blank">' . esc_html__('upgrade your plan', 'altomatic') . '</a>'
        ) . '</p>';
        echo '</div>';
    }
    ?>
<div class="wrap altomatic">
    <div class="altomatic-header">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
    </div>



    <!-- Quick Links Bar -->
    <div class="altomatic-quick-links" style="margin-bottom: 20px; padding: 15px; background: #fff; border: 1px solid #ccd0d4; border-radius: 4px;">
        <div style="display: flex; gap: 20px; align-items: center;">
            <a href="<?php echo esc_url(admin_url('upload.php?page=altomatic-bulk')); ?>" class="button button-secondary btnalto">
                <span class="dashicons dashicons-images-alt2" style="margin: 4px 5px 0 -2px;"></span>
                Bulk Optimization
            </a>
            <a href="https://altomatic.ai/profile" target="_blank" class="button button-secondary btnalto">
                <span class="dashicons dashicons-admin-users" style="margin: 4px 5px 0 -2px;"></span>
                Manage Account
            </a>
            <a href="mailto:support@altomatic.ai" class="button button-secondary btnalto">
                <span class="dashicons dashicons-email" style="margin: 4px 5px 0 -2px;"></span>
                Contact Support
            </a>
        </div>
    </div>

    <!-- Info Tabs -->
    <div class="altomatic-info-tabs" style="margin-bottom: 20px;">
        <div class="nav-tab-wrapper">
            <button class="nav-tab nav-tab-active" data-tab="getting-started">Getting Started</button>
            <button class="nav-tab" data-tab="how-it-works">How It Works</button>
            <button class="nav-tab" data-tab="tips">Tips & Best Practices</button>
        </div>

        <!-- Tab Content -->
        <div class="tab-content" style="background: #fff; border: 1px solid #ccd0d4; border-top: none; padding: 20px;">
            <!-- Getting Started -->
            <div class="tab-pane active" id="getting-started">
                <h3 style="margin-top: 0;">Quick Start Guide</h3>
                <ol style="margin: 0;">
                    <li>Enter your API key from <a href="https://altomatic.ai/profile" target="_blank">altomatic.ai</a> (free plan available)</li>
                    <li>Choose which image sizes to optimize</li>
                    <li>Select your preferred formats (WebP recommended)</li>
                    <li>Enable automatic alt text generation if desired</li>
                    <li>Start optimizing images directly in the media library or from the <a href="<?php echo esc_url(admin_url('upload.php?page=altomatic-bulk')); ?>">bulk optimization page</a></li>
                </ol>
            </div>

            <!-- How It Works -->
            <div class="tab-pane" id="how-it-works" style="display: none;">
                <h3 style="margin-top: 0;">Understanding Credits</h3>
                <ul style="margin: 0;">
                    <li>Image optimization: 1 credit per image size</li>
                    <li>Each format (Original, WebP, AVIF) uses 1 credit per size or format</li>
                    <li>AI alt text generation: 3 credits per image</li>
                    <li>Monitor usage or upgrade/manage your plan in your <a href="https://altomatic.ai/profile" target="_blank">Altomatic dashboard</a></li>
                </ul>
            </div>

            <!-- Tips -->
            <div class="tab-pane" id="tips" style="display: none;">
                <h3 style="margin-top: 0;">Optimization Tips</h3>
                <ul style="margin: 0;">
                    <li>Enable WebP for better compression and browser support</li>
                    <li>Use AVIF sparingly - best for thumbnail and medium sizes (this format is not supported in all browsers and is newer so not all sizes are supported through the API)</li>
                    <li>Keep srcset optimization enabled for responsive images for seemless WordPress image loading</li>
                    <li>Run bulk optimization to update the whole media library at once</li>
                </ul>
            </div>
        </div>
    </div>

    <script>
    jQuery(document).ready(function($) {
        // Tab switching
        $('.nav-tab').on('click', function() {
            // Remove active class from all tabs
            $('.nav-tab').removeClass('nav-tab-active');
            $(this).addClass('nav-tab-active');

            // Hide all tab panes
            $('.tab-pane').hide();

            // Show the selected tab pane
            $('#' + $(this).data('tab')).show();
        });
    });
    </script>

    <form method="post" action="options.php">
        <?php settings_fields('altomatic_settings'); ?>

        <!-- Hidden fields to ensure empty arrays are submitted -->
        <input type="hidden" name="altomatic_format_conversion[]" value="" disabled>
        <input type="hidden" name="altomatic_image_sizes[]" value="" disabled>

        <table class="form-table" role="presentation">
            <!-- API Key -->
            <tr>
                <th scope="row">
                    <label for="altomatic_api_key"><?php esc_html_e('API Key', 'altomatic'); ?></label>
                </th>
                <td>
                    <div class="api-key-wrapper" style="display: flex; align-items: center; gap: 8px;">
                        <input type="password"
                               id="altomatic_api_key"
                               name="altomatic_api_key"
                               value="<?php echo esc_attr(get_option('altomatic_api_key')); ?>"
                               class="regular-text"
                               autocomplete="off">
                        <span class="status-icon"></span>
                        <button type="button" class="button button-secondary toggle-api-key" aria-label="<?php esc_attr_e('Toggle API key visibility', 'altomatic'); ?>">
                            <span class="dashicons dashicons-visibility"></span>
                        </button>
                    </div>
                    <p class="description"><?php esc_html_e('Enter your Altomatic API key', 'altomatic'); ?></p>

                    <!-- API Status Section -->
                    <div class="altomatic-api-status" style="display: none;">
                        <div class="api-credit-info">
                            <div class="credit-usage">
                                <span class="credit-count"></span>
                            </div>
                            <div class="credit-period">
                                <span class="period-text"></span>
                            </div>
                        </div>
                    </div>
                </td>
            </tr>

            <!-- Alt Text Generation -->
            <tr>
                <th scope="row">
                    <label for="altomatic_auto_generate_alt"><?php esc_html_e('Alt Text Generation', 'altomatic'); ?></label>
                </th>
                <td>
                    <label>
                        <input type="checkbox"
                               id="altomatic_auto_generate_alt"
                               name="altomatic_auto_generate_alt"
                               value="1"
                               <?php checked(get_option('altomatic_auto_generate_alt', true), true); ?>>
                        <?php esc_html_e('Automatically generate alt text for images', 'altomatic'); ?>
                    </label>
                </td>
            </tr>

            <!-- Format on Upload -->
            <tr>
                <th scope="row">
                    <?php esc_html_e('Format on Upload', 'altomatic'); ?>
                </th>
                <td>
                    <label>
                        <input type="checkbox"
                               id="altomatic_format_on_upload"
                               name="altomatic_format_on_upload"
                               value="1"
                               <?php checked(get_option('altomatic_format_on_upload', true), true); ?>>
                        <?php esc_html_e('Optimize images on upload', 'altomatic'); ?>
                    </label>
                    <p class="description"><?php esc_html_e('Automatically optimize images when they are uploaded to your site.', 'altomatic'); ?></p>
                </td>
            </tr>


            <!-- Format Conversion -->
            <tr>
                <th scope="row">
                    <?php esc_html_e('Format Conversion', 'altomatic'); ?>
                </th>
                <td>
                    <fieldset class="altomatic-format-conversion">
                        <!-- Add a hidden field that will be disabled when any checkbox is checked -->
                        <input type="hidden" name="altomatic_format_conversion[]" value="" class="empty-value">
                        <label style="display: block; margin-bottom: 12px;">
                            <input type="checkbox"
                                   name="altomatic_format_conversion[]"
                                   value="keep"
                                   <?php checked(in_array('keep', $selected_formats), true); ?>>
                            <?php esc_html_e('Optimize Original', 'altomatic'); ?>
                        </label>
                        <label style="display: block; margin-bottom: 12px;">
                            <input type="checkbox"
                                   name="altomatic_format_conversion[]"
                                   value="webp"
                                   <?php checked(in_array('webp', $selected_formats), true); ?>>
                            <?php esc_html_e('Create WebP', 'altomatic'); ?>
                        </label>
                        <label style="display: block; margin-bottom: 12px;">
                            <input type="checkbox"
                                   name="altomatic_format_conversion[]"
                                   value="avif"
                                   <?php checked(in_array('avif', $selected_formats), true); ?>>
                            <?php esc_html_e('Create AVIF', 'altomatic'); ?>
                        </label>
                    </fieldset>
                    <p class="description">
                        <?php esc_html_e('Choose which format(s) should be optimized, and created if needed.', 'altomatic'); ?>
                        <br>
                        <em><?php esc_html_e('Note: If AVIF is selected, only thumbnail and medium sizes will be created (if chosen below).', 'altomatic'); ?></em>
                    </p>
                </td>
            </tr>

            <!-- Image Sizes -->
            <tr>
                <th scope="row">
                    <?php esc_html_e('Image Sizes', 'altomatic'); ?>
                </th>
                <td>
                    <fieldset class="altomatic-image-sizes">
                        <!-- Add a hidden field that will be disabled when any checkbox is checked -->
                        <input type="hidden" name="altomatic_image_sizes[]" value="" class="empty-value">
                        <!-- Original size -->
                        <label style="display: block; margin-bottom: 12px;">
                            <input type="checkbox"
                                   name="altomatic_image_sizes[]"
                                   value="full"
                                   <?php checked(in_array('full', $selected_sizes), true); ?>>
                            <?php esc_html_e('Original size', 'altomatic'); ?>
                        </label>

                        <?php
                        // Intermediate sizes
                        foreach ($image_sizes as $size) {
                            if ($size === 'full') continue;

                            $label = ucfirst(str_replace('_', ' ', $size));
                            $dimensions = '';

                            // Get dimensions for core sizes
                            if ($size === 'thumbnail') {
                                $width = get_option('thumbnail_size_w');
                                $height = get_option('thumbnail_size_h');
                                $dimensions = " ({$width}x{$height})";
                            } elseif ($size === 'medium') {
                                $width = get_option('medium_size_w');
                                $height = get_option('medium_size_h');
                                $dimensions = " ({$width}x{$height})";
                            } elseif ($size === 'medium_large') {
                                $width = get_option('medium_large_size_w', 768);
                                $dimensions = " ({$width}x?)";
                            } elseif ($size === 'large') {
                                $width = get_option('large_size_w');
                                $height = get_option('large_size_h');
                                $dimensions = " ({$width}x{$height})";
                            }
                            ?>
                            <label style="display: block; margin-bottom: 12px;">
                                <input type="checkbox"
                                       name="altomatic_image_sizes[]"
                                       value="<?php echo esc_attr($size); ?>"
                                       <?php checked(in_array($size, $selected_sizes), true); ?>>
                                <?php echo esc_html($label . $dimensions); ?>
                            </label>
                            <?php
                        }
                        ?>
                    </fieldset>
                    <p class="description"><?php esc_html_e('Choose which image sizes should be optimized. Note: each image size uses 1 credit.', 'altomatic'); ?></p>
                </td>
            </tr>
            <!-- Srcset Optimization Setting -->
            <tr>
                <th scope="row">
                <label for="altomatic_enable_srcset_optimization"><?php esc_html_e('Srcset Optimization', 'altomatic'); ?></label>
                </th>
                <td>
                <label>
                    <input type="checkbox"
                        id="altomatic_enable_srcset_optimization"
                        name="altomatic_enable_srcset_optimization"
                        value="1"
                        <?php checked(get_option('altomatic_enable_srcset_optimization', true), true); ?>>
                    <?php esc_html_e('Optimize image URLs in srcset attributes (Recommended)', 'altomatic'); ?>
                </label>
                <p class="description">
                    <?php esc_html_e('Replaces standard image URLs in srcset with optimized versions (AVIF > WebP > Optimized Original) where available.', 'altomatic'); ?>
                </p>
                </td>
            </tr>
            <!-- Debug Logging -->
                <tr>
                    <th scope="row">
                        <label for="altomatic_enable_debug_logging"><?php esc_html_e('Debug Logging', 'altomatic'); ?></label>
                    </th>
                    <td>
                        <label>
                            <input type="checkbox"
                                id="altomatic_enable_debug_logging"
                                name="altomatic_enable_debug_logging"
                                value="1"
                                <?php checked(get_option('altomatic_enable_debug_logging', false), true); ?>>
                            <?php esc_html_e('Enable debug logging', 'altomatic'); ?>
                        </label>
                        <p class="description">
                            <?php esc_html_e('Enables logging of debug information to the WordPress error log.', 'altomatic'); ?>
                        </p>
                    </td>
                </tr>
        </table>

        <?php submit_button(); ?>
    </form>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Handle format conversion checkboxes
    const formatCheckboxes = document.querySelectorAll('input[name="altomatic_format_conversion[]"][type="checkbox"]');
    const formatEmptyValue = document.querySelector('input[name="altomatic_format_conversion[]"].empty-value');

    formatCheckboxes.forEach(checkbox => {
        checkbox.addEventListener('change', function() {
            const anyChecked = Array.from(formatCheckboxes).some(cb => cb.checked);
            formatEmptyValue.disabled = anyChecked;
        });
    });

    // Handle image sizes checkboxes
    const sizeCheckboxes = document.querySelectorAll('input[name="altomatic_image_sizes[]"][type="checkbox"]');
    const sizeEmptyValue = document.querySelector('input[name="altomatic_image_sizes[]"].empty-value');

    sizeCheckboxes.forEach(checkbox => {
        checkbox.addEventListener('change', function() {
            const anyChecked = Array.from(sizeCheckboxes).some(cb => cb.checked);
            sizeEmptyValue.disabled = anyChecked;
        });
    });

    // Initial state
    formatEmptyValue.disabled = Array.from(formatCheckboxes).some(cb => cb.checked);
    sizeEmptyValue.disabled = Array.from(sizeCheckboxes).some(cb => cb.checked);
});
</script>
