<?php
/**
 * Plugin Name: Altomatic
 * Plugin URI: https://altomatic.ai/wordpress
 * Description: AI-powered image optimization and alt text generation for WordPress
 * Version: 1.0.0
 * Author: Altomatic.ai
 * Author URI: https://altomatic.ai
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: altomatic
 *
 * @package Altomatic
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

// Define plugin constants
define('ALTOMATIC_VERSION', '1.0.0');
define('ALTOMATIC_PATH', plugin_dir_path(__FILE__));
define('ALTOMATIC_URL', plugin_dir_url(__FILE__));
define('WORDPRESS_PLUGIN_RUNTIME', true);

// Load required files
require_once ALTOMATIC_PATH . 'includes/class-altomatic.php';
require_once ALTOMATIC_PATH . 'includes/class-altomatic-api.php';

/**
 * Add settings link to plugins page
 */
add_filter('plugin_action_links_' . plugin_basename(__FILE__), function($links) {
    $settings_link = '<a href="' . admin_url('options-general.php?page=altomatic') . '">' . __('Settings', 'altomatic') . '</a>';
    array_unshift($links, $settings_link);
    return $links;
});

/**
 * The code that runs during plugin activation.
 */
function activate_altomatic() {
    require_once plugin_dir_path(__FILE__) . 'includes/class-altomatic-activator.php';
    Altomatic_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 */
function deactivate_altomatic() {
    require_once plugin_dir_path(__FILE__) . 'includes/class-altomatic-deactivator.php';
    Altomatic_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_altomatic');
register_deactivation_hook(__FILE__, 'deactivate_altomatic');

/**
 * Begins execution of the plugin.
 */
function run_altomatic() {
    static $plugin = null;
    
    if ($plugin === null) {
        $plugin = new Altomatic();
    }
}

// Start the plugin
run_altomatic(); 